@@ -1,10 +1,10 @@
 package Net::DNS::RR::A;
 
 #
-# $Id: A.pm 1037 2012-10-24 21:50:15Z willem $
+# $Id: A.pm 1043 2012-11-01 22:30:17Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1037 $)[1];
+$VERSION = (qw$LastChangedRevision: 1043 $)[1];
 
 use base Net::DNS::RR;
 
@@ -30,7 +30,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 sub encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless length $self->{address};
+	return '' unless $self->{address} && length $self->{address};
 	return pack 'a4', $self->{address};
 }
 
@@ -38,7 +38,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless length $self->{address};
+	return '' unless $self->{address} && length $self->{address};
 	return $self->address;
 }
 
